using System;
using System.Runtime.InteropServices;
using SharpDX;
using SharpDX.Direct3D9;
using SharpDX.Windows;

[StructLayout(LayoutKind.Sequential, Pack = 1)]
public struct AdapterInfo
{
    [MarshalAs(UnmanagedType.ByValArray, SizeConst=0x10)]
    public int[] AAList;
    [MarshalAs(UnmanagedType.ByValTStr, SizeConst=0x20)]
    public string AdapterName;
    [MarshalAs(UnmanagedType.ByValTStr, SizeConst=0x200)]
    public string AdapterDescription;
    public Guid DeviceGUID;
    [MarshalAs(UnmanagedType.ByValTStr, SizeConst=0x200)]
    public string AdapterID;
    public int DisplayNo;
    [MarshalAs(UnmanagedType.ByValArray, SizeConst=100)]
    public Resolution[] AResArray;
    public int NoOfRes;
    public int NoOfAA;
    public uint DepthFormat;
    public int MaxTexHeight;
    public int MaxTexWidth;
    public int DefaultResIndex;
    public string DisplayName
    {
        get
        {
            if (this.DisplayNo == -1)
            {
                return this.AdapterDescription;
            }
            return string.Concat(new object[] { this.AdapterDescription, " (#", this.DisplayNo, ")" });
        }
    }

    public AdapterInfo(int i)
    {
        AdapterDetails details = new AdapterDetails();
        GlobalDefs.D3D.GetAdapterIdentifier(i, 0, out details);

        AAList = new int[2];
        AdapterName = details.DeviceName;
        AdapterDescription = details.Description;
        Capabilities caps = new Capabilities();
        GlobalDefs.D3D.GetDeviceCaps(i, DeviceType.Hardware, out caps);

        DeviceGUID = details.DeviceIdentifier;
        AdapterID = details.Driver;
        DisplayNo = 0;
        AResArray = new Resolution[1];
        DisplayMode mode = new DisplayMode();
        GlobalDefs.D3D.GetAdapterDisplayMode(i, out mode);
        AResArray[0].Width = mode.Width;
        AResArray[0].Height = mode.Height;
        AResArray[0].Refresh = mode.RefreshRate;

        NoOfRes = 1;// GlobalDefs.D3D.GetAdapterModeCount(i, Format.Unknown);
        NoOfAA = 2;
        DepthFormat = FourCC.GetFourCC("INTZ");
        MaxTexHeight = caps.MaxTextureHeight;
        MaxTexWidth = caps.MaxTextureWidth;
        DefaultResIndex = 0;
    }
}

public static class FourCC
{
    public static uint GetFourCC(string code)
    {
        return (uint)((code[3] << 24) + (code[2] << 16) + (code[1] << 8) + code[0]);
    }
}
