namespace Generations_Launcher_Front
{
    using Generations_Launcher_Front.TextStore;
    using System;
    using System.Collections.Generic;
    using System.ComponentModel;
    using System.Drawing;
    using System.Windows.Forms;
    using SharpDX;
    using SharpDX.Direct3D9;
    using SharpDX.Windows;

    public class GraphicsConfiguration : UserControl
    {
        private ComboBox AA_Combo;
        private Label AA_label;
        private ComboBox Adapter_Combo;
        private Label Adapter_label;
        private IContainer components;
        private Label DisplayMode_Label;
        private ComboBox DispMode_combo;
        private Label Graphics_Label;
        private List<AATypes> mAATypesList;
        private List<DisplayModes> mDisplayModesList;
        private List<AdapterInfo> mGraphicsAdapterList;
        private List<LowHigh> mReflectionList;
        private List<LowHigh> mShadowList;
        private List<OnOff> mVsyncList;
        private Label NoAdapterWarning_label;
        private PictureBox pictureBox1;
        private CheckBox Reflection_Check;
        private ComboBox Reflection_Combo;
        private Label Reflection_Label;
        private Label Res_label;
        private ComboBox Resolution_Combo;
        private CheckBox Shadow_Check;
        private ComboBox Shadow_Combo;
        private Label Shadow_Label;
        private CheckBox VSync_Check;
        private ComboBox Vsync_combo;
        private Label vsync_label;
        private CheckBox Windowed_Check;

        public GraphicsConfiguration()
        {
            this.InitializeComponent();
            this.mGraphicsAdapterList = new List<AdapterInfo>();
            this.mDisplayModesList = new List<DisplayModes>();
            this.mAATypesList = new List<AATypes>();
            this.mShadowList = new List<LowHigh>();
            this.mReflectionList = new List<LowHigh>();
            this.mVsyncList = new List<OnOff>();
        }

        private void AA_Combo_SelectedIndexChanged(object sender, EventArgs e)
        {
            int selectedIndex = this.Adapter_Combo.SelectedIndex;
            int index = this.AA_Combo.SelectedIndex;
            if (((selectedIndex >= 0) && (selectedIndex < this.mGraphicsAdapterList.Count)) && ((index >= 0) && (index < this.mGraphicsAdapterList[selectedIndex].AAList.Length)))
            {
                GlobalDefs.OutputAdapter.AA = this.mGraphicsAdapterList[selectedIndex].AAList[index];
            }
        }

        private void Adapter_Combo_SelectedIndexChanged(object sender, EventArgs e)
        {
            this.Resolution_Combo.DataSource = null;
            this.Resolution_Combo.Items.Clear();
            this.Resolution_Combo.DataSource = this.mGraphicsAdapterList[this.Adapter_Combo.SelectedIndex].AResArray;
            this.Resolution_Combo.DisplayMember = "DisplayName";
            this.Resolution_Combo.SelectedIndex = 0;
            this.AA_Combo.DataSource = null;
            this.AA_Combo.Items.Clear();
            this.AA_Combo.DataSource = this.mAATypesList;
            this.AA_Combo.DisplayMember = "DisplayName";
            this.AA_Combo.SelectedIndex = 0;
            int selectedIndex = this.Adapter_Combo.SelectedIndex;
            GlobalDefs.OutputAdapter.AdapterDescription = this.mGraphicsAdapterList[selectedIndex].AdapterDescription;
            GlobalDefs.OutputAdapter.AdapterName = this.mGraphicsAdapterList[selectedIndex].AdapterName;
            GlobalDefs.OutputAdapter.DeviceGUID = this.mGraphicsAdapterList[selectedIndex].DeviceGUID;
            GlobalDefs.OutputAdapter.AdapterID = this.mGraphicsAdapterList[selectedIndex].AdapterID;
            GlobalDefs.OutputAdapter.DepthFormat = this.mGraphicsAdapterList[selectedIndex].DepthFormat;
            if (this.Resolution_Combo.SelectedIndex != -1)
            {
                this.Resolution_Combo.SelectedIndex = this.mGraphicsAdapterList[this.Adapter_Combo.SelectedIndex].DefaultResIndex;
            }
            if (this.AA_Combo.SelectedIndex != -1)
            {
                this.AA_Combo.SelectedIndex = 0;
            }
        }

        private void DispMode_combo_SelectedIndexChanged(object sender, EventArgs e)
        {
            GlobalDefs.OutputAdapter.DisplayMode = this.DispMode_combo.SelectedIndex == 1;
        }

        protected override void Dispose(bool disposing)
        {
            if (disposing && (this.components != null))
            {
                this.components.Dispose();
            }
            base.Dispose(disposing);
        }

        private void DressText()
        {
            this.Graphics_Label.Text = LocalizedText.Graphics_Label;
            this.Adapter_label.Text = LocalizedText.Adapter_label;
            this.Res_label.Text = LocalizedText.Res_label;
            this.AA_label.Text = LocalizedText.AA_label;
            this.VSync_Check.Text = LocalizedText.VSync_Check;
            this.vsync_label.Text = LocalizedText.VSync_Check;
            this.Windowed_Check.Text = LocalizedText.Windowed_Check;
            this.NoAdapterWarning_label.Text = LocalizedText.NoValidAdapter_Label;
            this.Shadow_Label.Text = LocalizedText.Shadow_Check;
            this.Reflection_Label.Text = LocalizedText.Reflection_Check;
            this.DisplayMode_Label.Text = LocalizedText.DisplayMode_Label;
        }

        private void GraphicsConfiguration_Load(object sender, EventArgs e)
        {
            int num;

            num = GlobalDefs.D3D.AdapterCount;

            if (num <= 0)
            {
                GlobalDefs defs = new GlobalDefs();
                this.Adapter_Combo.Enabled = false;
                this.Resolution_Combo.Enabled = false;
                this.AA_Combo.Enabled = false;
                this.VSync_Check.Enabled = false;
                this.DispMode_combo.Enabled = false;
                this.Shadow_Combo.Enabled = false;
                this.Reflection_Combo.Enabled = false;
                this.Vsync_combo.Enabled = false;
                this.NoAdapterWarning_label.Visible = true;
                GlobalDefs.OutputAdapter.AdapterDescription = "";
                GlobalDefs.OutputAdapter.AdapterName = "";
                GlobalDefs.OutputAdapter.DeviceGUID = defs.ZERO_GUID;
                GlobalDefs.OutputAdapter.AdapterID = "";
                GlobalDefs.OutputAdapter.OutputRes.Height = 0;
                GlobalDefs.OutputAdapter.OutputRes.Refresh = 0;
                GlobalDefs.OutputAdapter.OutputRes.Width = 0;
                GlobalDefs.OutputAdapter.ValidAdapter = false;
                GlobalDefs.OutputAdapter.DisplayMode = false;
                GlobalDefs.OutputAdapter.ShadQuality = false;
                GlobalDefs.OutputAdapter.ReflectQuality = false;
            }
            else
            {
                bool displayMode;
                bool shadQuality;
                bool reflectQuality;
                bool bVSync;
                this.Adapter_Combo.Enabled = true;
                this.Resolution_Combo.Enabled = true;
                this.AA_Combo.Enabled = true;
                this.Vsync_combo.Enabled = true;
                this.NoAdapterWarning_label.Visible = false;
                GlobalDefs.OutputAdapter.ValidAdapter = true;
                DisplayModes item = new DisplayModes();
                item.modeNo = 0;
                this.mDisplayModesList.Add(item);
                item.modeNo = 1;
                this.mDisplayModesList.Add(item);
                LowHigh high = new LowHigh();
                high.bIsHigh = true;
                this.mShadowList.Add(high);
                this.mReflectionList.Add(high);
                high.bIsHigh = false;
                this.mShadowList.Add(high);
                this.mReflectionList.Add(high);
                OnOff off = new OnOff();
                off.bVsync = true;
                this.mVsyncList.Add(off);
                off.bVsync = false;
                this.mVsyncList.Add(off);
                for (int i = 0; i < num; i++)
                {
                    AdapterInfo aI = new AdapterInfo(i);
                    Array.Resize<Resolution>(ref aI.AResArray, aI.NoOfRes);
                    aI.AAList[0] = 0;
                    aI.AAList[1] = 1;
                    Array.Resize<int>(ref aI.AAList, 2);
                    this.mGraphicsAdapterList.Add(aI);
                }
                int num3 = 0;
                int num4 = 0;
                int num5 = 0;
                foreach (AdapterInfo info2 in this.mGraphicsAdapterList)
                {
                    if ((info2.AdapterDescription == GlobalDefs.OutputAdapter.AdapterDescription) && (info2.AdapterName == GlobalDefs.OutputAdapter.AdapterName))
                    {
                        num4 = num3;
                        break;
                    }
                    num3++;
                }
                int defaultResIndex = this.mGraphicsAdapterList[num4].DefaultResIndex;
                num3 = 0;
                foreach (Resolution resolution in this.mGraphicsAdapterList[num4].AResArray)
                {
                    if (resolution.DisplayName == GlobalDefs.OutputAdapter.OutputRes.DisplayName)
                    {
                        defaultResIndex = num3;
                        break;
                    }
                    num3++;
                }
                num3 = 0;
                foreach (int num7 in this.mGraphicsAdapterList[num4].AAList)
                {
                    if (num7 == GlobalDefs.OutputAdapter.AA)
                    {
                        num5 = num3;
                        break;
                    }
                    num3++;
                }
                this.Adapter_Combo.DataSource = null;
                this.Adapter_Combo.Items.Clear();
                this.Adapter_Combo.DataSource = this.mGraphicsAdapterList;
                this.Adapter_Combo.DisplayMember = "DisplayName";
                this.Adapter_Combo.SelectedIndex = num4;
                this.Resolution_Combo.SelectedIndex = defaultResIndex;
                if (this.mAATypesList.Count > num5)
                {
                    this.AA_Combo.SelectedIndex = num5;
                }
                else
                {
                    this.AA_Combo.SelectedIndex = 0;
                }
                if (GlobalDefs.GraphicsConfigFileRead)
                {
                    this.Windowed_Check.Checked = GlobalDefs.OutputAdapter.bWindowed;
                    shadQuality = GlobalDefs.OutputAdapter.ShadQuality;
                    reflectQuality = GlobalDefs.OutputAdapter.ReflectQuality;
                    displayMode = GlobalDefs.OutputAdapter.DisplayMode;
                    bVSync = GlobalDefs.OutputAdapter.bVSync;
                }
                else
                {
                    this.Windowed_Check.Checked = true;
                    this.VSync_Check.Checked = true;
                    shadQuality = true;
                    reflectQuality = true;
                    displayMode = false;
                    bVSync = true;
                }
                this.DispMode_combo.DataSource = null;
                this.DispMode_combo.Items.Clear();
                this.DispMode_combo.DataSource = this.mDisplayModesList;
                this.DispMode_combo.DisplayMember = "DisplayName";
                if (displayMode)
                {
                    this.DispMode_combo.SelectedIndex = 1;
                }
                else
                {
                    this.DispMode_combo.SelectedIndex = 0;
                }
                this.Shadow_Combo.DataSource = null;
                this.Shadow_Combo.Items.Clear();
                this.Shadow_Combo.DataSource = this.mShadowList;
                this.Shadow_Combo.DisplayMember = "DisplayName";
                if (shadQuality)
                {
                    this.Shadow_Combo.SelectedIndex = 0;
                }
                else
                {
                    this.Shadow_Combo.SelectedIndex = 1;
                }
                this.Reflection_Combo.DataSource = null;
                this.Reflection_Combo.Items.Clear();
                this.Reflection_Combo.DataSource = this.mReflectionList;
                this.Reflection_Combo.DisplayMember = "DisplayName";
                if (reflectQuality)
                {
                    this.Reflection_Combo.SelectedIndex = 0;
                }
                else
                {
                    this.Reflection_Combo.SelectedIndex = 1;
                }
                this.Vsync_combo.DataSource = null;
                this.Vsync_combo.Items.Clear();
                this.Vsync_combo.DataSource = this.mVsyncList;
                this.Vsync_combo.DisplayMember = "DisplayName";
                if (bVSync)
                {
                    this.Vsync_combo.SelectedIndex = 0;
                }
                else
                {
                    this.Vsync_combo.SelectedIndex = 1;
                }
            }
            this.DressText();
        }

        private void InitializeComponent()
        {
            ComponentResourceManager manager = new ComponentResourceManager(typeof(GraphicsConfiguration));
            this.Graphics_Label = new Label();
            this.Adapter_Combo = new ComboBox();
            this.Resolution_Combo = new ComboBox();
            this.AA_Combo = new ComboBox();
            this.Adapter_label = new Label();
            this.Res_label = new Label();
            this.AA_label = new Label();
            this.VSync_Check = new CheckBox();
            this.Windowed_Check = new CheckBox();
            this.NoAdapterWarning_label = new Label();
            this.DisplayMode_Label = new Label();
            this.DispMode_combo = new ComboBox();
            this.Shadow_Check = new CheckBox();
            this.Reflection_Check = new CheckBox();
            this.Shadow_Combo = new ComboBox();
            this.Reflection_Combo = new ComboBox();
            this.Shadow_Label = new Label();
            this.Reflection_Label = new Label();
            this.pictureBox1 = new PictureBox();
            this.Vsync_combo = new ComboBox();
            this.vsync_label = new Label();
            ((ISupportInitialize) this.pictureBox1).BeginInit();
            base.SuspendLayout();
            this.Graphics_Label.Location = new Point(3, 0);
            this.Graphics_Label.Name = "Graphics_Label";
            this.Graphics_Label.Size = new System.Drawing.Size(0x132, 0x27);
            this.Graphics_Label.TabIndex = 0;
            this.Graphics_Label.Text = "Graphics Configuration";
            this.Adapter_Combo.DropDownStyle = ComboBoxStyle.DropDownList;
            this.Adapter_Combo.FormattingEnabled = true;
            this.Adapter_Combo.Location = new Point(20, 0x30);
            this.Adapter_Combo.Name = "Adapter_Combo";
            this.Adapter_Combo.Size = new System.Drawing.Size(300, 0x15);
            this.Adapter_Combo.TabIndex = 1;
            this.Adapter_Combo.SelectedIndexChanged += new EventHandler(this.Adapter_Combo_SelectedIndexChanged);
            this.Resolution_Combo.DropDownStyle = ComboBoxStyle.DropDownList;
            this.Resolution_Combo.FormattingEnabled = true;
            this.Resolution_Combo.Location = new Point(20, 0x62);
            this.Resolution_Combo.Name = "Resolution_Combo";
            this.Resolution_Combo.Size = new System.Drawing.Size(300, 0x15);
            this.Resolution_Combo.TabIndex = 2;
            this.Resolution_Combo.SelectedIndexChanged += new EventHandler(this.Resolution_Combo_SelectedIndexChanged);
            this.AA_Combo.DropDownStyle = ComboBoxStyle.DropDownList;
            this.AA_Combo.FormattingEnabled = true;
            this.AA_Combo.Location = new Point(20, 0x94);
            this.AA_Combo.Name = "AA_Combo";
            this.AA_Combo.Size = new System.Drawing.Size(300, 0x15);
            this.AA_Combo.TabIndex = 3;
            this.AA_Combo.SelectedIndexChanged += new EventHandler(this.AA_Combo_SelectedIndexChanged);
            this.Adapter_label.AutoSize = true;
            this.Adapter_label.Location = new Point(0x1b, 0x20);
            this.Adapter_label.Name = "Adapter_label";
            this.Adapter_label.Size = new System.Drawing.Size(0x59, 13);
            this.Adapter_label.TabIndex = 4;
            this.Adapter_label.Text = "Graphics Adapter";
            this.Res_label.AutoSize = true;
            this.Res_label.Location = new Point(0x1b, 0x52);
            this.Res_label.Name = "Res_label";
            this.Res_label.Size = new System.Drawing.Size(0x39, 13);
            this.Res_label.TabIndex = 5;
            this.Res_label.Text = "Resolution";
            this.AA_label.AutoSize = true;
            this.AA_label.Location = new Point(0x1b, 0x84);
            this.AA_label.Name = "AA_label";
            this.AA_label.Size = new System.Drawing.Size(0x3d, 13);
            this.AA_label.TabIndex = 6;
            this.AA_label.Text = "AntiAliasing";
            this.VSync_Check.AutoSize = true;
            this.VSync_Check.Enabled = false;
            this.VSync_Check.Location = new Point(0x9f, 0x1b6);
            this.VSync_Check.Name = "VSync_Check";
            this.VSync_Check.Size = new System.Drawing.Size(0x4b, 0x11);
            this.VSync_Check.TabIndex = 7;
            this.VSync_Check.Text = "V-Sync on";
            this.VSync_Check.UseVisualStyleBackColor = true;
            this.VSync_Check.Visible = false;
            this.VSync_Check.CheckedChanged += new EventHandler(this.VSync_Check_CheckedChanged);
            this.Windowed_Check.AutoSize = true;
            this.Windowed_Check.Enabled = false;
            this.Windowed_Check.Location = new Point(0x19c, 0x1b6);
            this.Windowed_Check.Name = "Windowed_Check";
            this.Windowed_Check.Size = new System.Drawing.Size(0x8d, 0x11);
            this.Windowed_Check.TabIndex = 8;
            this.Windowed_Check.Text = "Run in Windowed Mode";
            this.Windowed_Check.UseVisualStyleBackColor = true;
            this.Windowed_Check.Visible = false;
            this.Windowed_Check.CheckedChanged += new EventHandler(this.Windowed_Check_CheckedChanged);
            this.NoAdapterWarning_label.Font = new Font("Microsoft Sans Serif", 11.25f, FontStyle.Bold, GraphicsUnit.Point, 0);
            this.NoAdapterWarning_label.ForeColor = Color.DarkRed;
            this.NoAdapterWarning_label.Location = new Point(370, 0x83);
            this.NoAdapterWarning_label.Name = "NoAdapterWarning_label";
            this.NoAdapterWarning_label.Size = new System.Drawing.Size(0xed, 0x65);
            this.NoAdapterWarning_label.TabIndex = 9;
            this.NoAdapterWarning_label.Text = "No Compatible Graphics Adapter Found";
            this.NoAdapterWarning_label.TextAlign = ContentAlignment.MiddleCenter;
            this.NoAdapterWarning_label.Visible = false;
            this.DisplayMode_Label.AutoSize = true;
            this.DisplayMode_Label.Location = new Point(0x1b, 0xb6);
            this.DisplayMode_Label.Name = "DisplayMode_Label";
            this.DisplayMode_Label.Size = new System.Drawing.Size(0x47, 13);
            this.DisplayMode_Label.TabIndex = 10;
            this.DisplayMode_Label.Text = "Display Mode";
            this.DispMode_combo.DropDownStyle = ComboBoxStyle.DropDownList;
            this.DispMode_combo.FormattingEnabled = true;
            this.DispMode_combo.Location = new Point(20, 0xc6);
            this.DispMode_combo.Name = "DispMode_combo";
            this.DispMode_combo.Size = new System.Drawing.Size(300, 0x15);
            this.DispMode_combo.TabIndex = 11;
            this.DispMode_combo.SelectedIndexChanged += new EventHandler(this.DispMode_combo_SelectedIndexChanged);
            this.Shadow_Check.AutoSize = true;
            this.Shadow_Check.Enabled = false;
            this.Shadow_Check.Location = new Point(240, 440);
            this.Shadow_Check.Name = "Shadow_Check";
            this.Shadow_Check.Size = new System.Drawing.Size(80, 0x11);
            this.Shadow_Check.TabIndex = 12;
            this.Shadow_Check.Text = "checkBox1";
            this.Shadow_Check.UseVisualStyleBackColor = true;
            this.Shadow_Check.Visible = false;
            this.Shadow_Check.CheckedChanged += new EventHandler(this.Shadow_Check_CheckedChanged);
            this.Reflection_Check.AutoSize = true;
            this.Reflection_Check.Enabled = false;
            this.Reflection_Check.Location = new Point(0x146, 440);
            this.Reflection_Check.Name = "Reflection_Check";
            this.Reflection_Check.Size = new System.Drawing.Size(80, 0x11);
            this.Reflection_Check.TabIndex = 13;
            this.Reflection_Check.Text = "checkBox1";
            this.Reflection_Check.UseVisualStyleBackColor = true;
            this.Reflection_Check.Visible = false;
            this.Reflection_Check.CheckedChanged += new EventHandler(this.Reflection_Check_CheckedChanged);
            this.Shadow_Combo.DropDownStyle = ComboBoxStyle.DropDownList;
            this.Shadow_Combo.FormattingEnabled = true;
            this.Shadow_Combo.Location = new Point(20, 0xf8);
            this.Shadow_Combo.Name = "Shadow_Combo";
            this.Shadow_Combo.Size = new System.Drawing.Size(300, 0x15);
            this.Shadow_Combo.TabIndex = 14;
            this.Shadow_Combo.SelectedIndexChanged += new EventHandler(this.Shadow_Combo_SelectedIndexChanged);
            this.Reflection_Combo.DropDownStyle = ComboBoxStyle.DropDownList;
            this.Reflection_Combo.FormattingEnabled = true;
            this.Reflection_Combo.Location = new Point(20, 0x12a);
            this.Reflection_Combo.Name = "Reflection_Combo";
            this.Reflection_Combo.Size = new System.Drawing.Size(300, 0x15);
            this.Reflection_Combo.TabIndex = 15;
            this.Reflection_Combo.SelectedIndexChanged += new EventHandler(this.Reflection_Combo_SelectedIndexChanged);
            this.Shadow_Label.Location = new Point(0x1b, 0xe8);
            this.Shadow_Label.Name = "Shadow_Label";
            this.Shadow_Label.Size = new System.Drawing.Size(0x80, 0x10);
            this.Shadow_Label.TabIndex = 0x10;
            this.Shadow_Label.Text = "shadow_label1";
            this.Reflection_Label.Location = new Point(0x1b, 0x11a);
            this.Reflection_Label.Name = "Reflection_Label";
            this.Reflection_Label.Size = new System.Drawing.Size(0x90, 15);
            this.Reflection_Label.TabIndex = 0x11;
            this.Reflection_Label.Text = "reflection_label1";
            this.pictureBox1.Image = (Image) manager.GetObject("pictureBox1.Image");
            this.pictureBox1.Location = new Point(0, 0);
            this.pictureBox1.Name = "pictureBox1";
            this.pictureBox1.Size = new System.Drawing.Size(0x34e, 460);
            this.pictureBox1.TabIndex = 0x12;
            this.pictureBox1.TabStop = false;
            this.Vsync_combo.DropDownStyle = ComboBoxStyle.DropDownList;
            this.Vsync_combo.FormattingEnabled = true;
            this.Vsync_combo.Location = new Point(20, 0x15c);
            this.Vsync_combo.Name = "Vsync_combo";
            this.Vsync_combo.Size = new System.Drawing.Size(300, 0x15);
            this.Vsync_combo.TabIndex = 0x13;
            this.Vsync_combo.SelectedIndexChanged += new EventHandler(this.Vsync_combo_SelectedIndexChanged);
            this.vsync_label.AutoSize = true;
            this.vsync_label.Location = new Point(0x1b, 0x14c);
            this.vsync_label.Name = "vsync_label";
            this.vsync_label.Size = new System.Drawing.Size(0x3f, 13);
            this.vsync_label.TabIndex = 20;
            this.vsync_label.Text = "vsync_label";
            base.AutoScaleDimensions = new SizeF(6f, 13f);
            base.AutoScaleMode = AutoScaleMode.Font;
            base.BorderStyle = BorderStyle.FixedSingle;
            base.Controls.Add(this.vsync_label);
            base.Controls.Add(this.Vsync_combo);
            base.Controls.Add(this.Reflection_Label);
            base.Controls.Add(this.Shadow_Label);
            base.Controls.Add(this.Reflection_Combo);
            base.Controls.Add(this.Shadow_Combo);
            base.Controls.Add(this.Reflection_Check);
            base.Controls.Add(this.Shadow_Check);
            base.Controls.Add(this.DispMode_combo);
            base.Controls.Add(this.DisplayMode_Label);
            base.Controls.Add(this.NoAdapterWarning_label);
            base.Controls.Add(this.Windowed_Check);
            base.Controls.Add(this.VSync_Check);
            base.Controls.Add(this.AA_label);
            base.Controls.Add(this.Res_label);
            base.Controls.Add(this.Adapter_label);
            base.Controls.Add(this.AA_Combo);
            base.Controls.Add(this.Resolution_Combo);
            base.Controls.Add(this.Adapter_Combo);
            base.Controls.Add(this.Graphics_Label);
            base.Controls.Add(this.pictureBox1);
            base.Name = "GraphicsConfiguration";
            base.Size = new System.Drawing.Size(0x34e, 460);
            base.Load += new EventHandler(this.GraphicsConfiguration_Load);
            ((ISupportInitialize) this.pictureBox1).EndInit();
            base.ResumeLayout(false);
            base.PerformLayout();
        }

        private void Reflection_Check_CheckedChanged(object sender, EventArgs e)
        {
        }

        private void Reflection_Combo_SelectedIndexChanged(object sender, EventArgs e)
        {
            GlobalDefs.OutputAdapter.ReflectQuality = this.Reflection_Combo.SelectedIndex == 0;
        }

        private void Resolution_Combo_SelectedIndexChanged(object sender, EventArgs e)
        {
            int selectedIndex = this.Adapter_Combo.SelectedIndex;
            int index = this.Resolution_Combo.SelectedIndex;
            int num3 = this.AA_Combo.SelectedIndex;
            if (((selectedIndex >= 0) && (selectedIndex < this.mGraphicsAdapterList.Count)) && ((index >= 0) && (index < this.mGraphicsAdapterList[selectedIndex].AResArray.Length)))
            {
                this.mAATypesList.Clear();
                AATypes item = new AATypes();
                item.AA = 0;
                this.mAATypesList.Add(item);
                item.AA = 1;
                this.mAATypesList.Add(item);
                GlobalDefs.OutputAdapter.OutputRes = this.mGraphicsAdapterList[selectedIndex].AResArray[index];
                if (this.mAATypesList.Count > num3)
                {
                    this.AA_Combo.SelectedIndex = num3;
                }
                else
                {
                    this.AA_Combo.SelectedIndex = 0;
                }
            }
        }

        private void Shadow_Check_CheckedChanged(object sender, EventArgs e)
        {
        }

        private void Shadow_Combo_SelectedIndexChanged(object sender, EventArgs e)
        {
            GlobalDefs.OutputAdapter.ShadQuality = this.Shadow_Combo.SelectedIndex == 0;
        }

        private void VSync_Check_CheckedChanged(object sender, EventArgs e)
        {
            GlobalDefs.OutputAdapter.bVSync = this.VSync_Check.Checked;
        }

        private void Vsync_combo_SelectedIndexChanged(object sender, EventArgs e)
        {
            GlobalDefs.OutputAdapter.bVSync = this.Vsync_combo.SelectedIndex == 0;
        }

        private void Windowed_Check_CheckedChanged(object sender, EventArgs e)
        {
            GlobalDefs.OutputAdapter.bWindowed = this.Windowed_Check.Checked;
        }
    }
}
