namespace Generations_Launcher_Front
{
    using Generations_Launcher_Front.TextStore;
    using System;
    using System.Collections.Generic;
    using System.ComponentModel;
    using System.Drawing;
    using System.IO;
    using System.Windows.Forms;

    public class InputConfiguration : UserControl
    {
        private Button ActiveButton;
        private bool bRefreshButtons;
        private Button ButtonA;
        private Button ButtonB;
        private Button ButtonBack;
        private Button ButtonLB;
        private Button ButtonLT;
        private Button ButtonRB;
        private Button ButtonRT;
        private Button ButtonStart;
        private Button ButtonStickXL;
        private Button ButtonStickXR;
        private Button ButtonStickYD;
        private Button ButtonStickYU;
        private Button ButtonX;
        private Button ButtonY;
        private IContainer components;
        public bool Found360Pad;
        private ComboBox InputType;
        private Label InputTypeLabel;
        public Timer InputUpdateTimer;
        private Label Instructions_label;
        private List<ButtonConfig> mButtonList;
        private List<PadInfo> mGuidPadInfoList;
        private List<ButtonConfig> mMovementButtonList;
        private List<ButtonConfig> mMovementButtonPairX;
        private List<ButtonConfig> mMovementButtonPairY;
        private byte MovementInputType;
        private List<PadInfo> mPadInfoList;
        private PictureBox pictureBox1;
        private PictureBox pictureBox2;
        private Button ResetDefaultButton;
        public Timer ResetTimer;
        private Label StartButtonInstructions_Label;

        public InputConfiguration()
        {
            this.InitializeComponent();
            this.mPadInfoList = new List<PadInfo>();
            this.mGuidPadInfoList = new List<PadInfo>();
            this.mButtonList = new List<ButtonConfig>();
            this.mMovementButtonList = new List<ButtonConfig>();
            this.mMovementButtonPairY = new List<ButtonConfig>();
            this.mMovementButtonPairX = new List<ButtonConfig>();
        }

        private void Button_Hover(object sender, EventArgs e)
        {
            this.ActiveButton = (Button) sender;
            this.ActiveButton.Focus();
        }

        private void Button_HoverLeave(object sender, EventArgs e)
        {
            this.ActiveButton = null;
        }

        private void ButtonStickLX_Click(object sender, EventArgs e)
        {
        }

        protected override void Dispose(bool disposing)
        {
            if (disposing && (this.components != null))
            {
                this.components.Dispose();
            }
            base.Dispose(disposing);
        }

        private void InitControllerSelections()
        {
            int num = DllExterns._GetPadListCount();
            string mProductName = "";
            if (this.InputType.SelectedIndex != -1)
            {
                PadInfo info = (PadInfo) this.InputType.Items[this.InputType.SelectedIndex];
                mProductName = info.mProductName;
            }
            GlobalDefs defs = new GlobalDefs();
            this.mPadInfoList.Clear();
            this.mGuidPadInfoList.Clear();
            DllExterns._FoundXInput(ref this.Found360Pad);
            if (this.Found360Pad)
            {
                this.mPadInfoList.Capacity = num + 1;
                this.mGuidPadInfoList.Capacity = num + 2;
                PadInfo info2 = new PadInfo();
                info2.mProductGuid = defs.ZERO_GUID;
                info2.mInstanceGuid = defs.ZERO_GUID;
                info2.mPadType = PadInfo.PAD_TYPE.PAD_TYPE_XBOX;
                info2.mInstanceID = 0;
                info2.mProductName = LocalizedText.Xbox_Pad_Name;
                this.mGuidPadInfoList.Add(info2);
            }
            else
            {
                this.mPadInfoList.Capacity = num + 1;
                this.mGuidPadInfoList.Capacity = num + 1;
            }
            PadInfo item = new PadInfo();
            item.mProductGuid = defs.KEYBOARD_GUID;
            item.mInstanceGuid = defs.ZERO_GUID;
            item.mPadType = PadInfo.PAD_TYPE.PAD_TYPE_KEYBOARD;
            item.mInstanceID = 0;
            item.mProductName = LocalizedText.Keyboard_Name;
            this.mPadInfoList.Add(item);
            this.mGuidPadInfoList.Add(item);
            int num2 = 1;
            bool flag = false;
            for (int i = 0; i < num; i++)
            {
                PadInfo lplf = new PadInfo();
                DllExterns._GetPadInfo(lplf, i);
                this.mPadInfoList.Add(lplf);
                foreach (PadInfo info5 in this.mGuidPadInfoList)
                {
                    if (info5.mProductGuid == lplf.mProductGuid)
                    {
                        flag = true;
                    }
                }
                if (!flag)
                {
                    this.mGuidPadInfoList.Add(lplf);
                    num2++;
                }
            }
            this.InputType.DataSource = null;
            this.InputType.Items.Clear();
            this.InputType.DataSource = this.mGuidPadInfoList;
            this.InputType.DisplayMember = "DisplayName";
            this.InputType.SelectedIndex = 0;
            this.UpdateConfigList();
            int num4 = 0;
            foreach (PadInfo info6 in this.InputType.Items)
            {
                if (info6.mProductName == mProductName)
                {
                    this.InputType.SelectedIndex = num4;
                    break;
                }
                num4++;
            }
        }

        private void InitializeComponent()
        {
            ComponentResourceManager manager = new ComponentResourceManager(typeof(InputConfiguration));
            this.ButtonA = new Button();
            this.ButtonB = new Button();
            this.InputType = new ComboBox();
            this.InputTypeLabel = new Label();
            this.ButtonX = new Button();
            this.ButtonY = new Button();
            this.ButtonRB = new Button();
            this.ButtonLB = new Button();
            this.ButtonBack = new Button();
            this.ButtonStart = new Button();
            this.ButtonLT = new Button();
            this.ButtonRT = new Button();
            this.ButtonStickYD = new Button();
            this.ButtonStickXL = new Button();
            this.ButtonStickYU = new Button();
            this.ButtonStickXR = new Button();
            this.ResetDefaultButton = new Button();
            this.pictureBox1 = new PictureBox();
            this.Instructions_label = new Label();
            this.pictureBox2 = new PictureBox();
            this.StartButtonInstructions_Label = new Label();
            ((ISupportInitialize) this.pictureBox1).BeginInit();
            ((ISupportInitialize) this.pictureBox2).BeginInit();
            base.SuspendLayout();
            this.ButtonA.Location = new Point(0x2bf, 0x13c);
            this.ButtonA.Name = "ButtonA";
            this.ButtonA.Size = new Size(0x49, 0x24);
            this.ButtonA.TabIndex = 1;
            this.ButtonA.Text = "button1";
            this.ButtonA.UseVisualStyleBackColor = true;
            this.ButtonA.Visible = false;
            this.ButtonA.MouseLeave += new EventHandler(this.Button_HoverLeave);
            this.ButtonA.MouseHover += new EventHandler(this.Button_Hover);
            this.ButtonB.Location = new Point(750, 270);
            this.ButtonB.Name = "ButtonB";
            this.ButtonB.Size = new Size(0x49, 0x24);
            this.ButtonB.TabIndex = 2;
            this.ButtonB.Text = "button2";
            this.ButtonB.UseVisualStyleBackColor = true;
            this.ButtonB.Visible = false;
            this.ButtonB.MouseLeave += new EventHandler(this.Button_HoverLeave);
            this.ButtonB.MouseHover += new EventHandler(this.Button_Hover);
            this.InputType.DropDownStyle = ComboBoxStyle.DropDownList;
            this.InputType.FormattingEnabled = true;
            this.InputType.Location = new Point(3, 0x1c);
            this.InputType.Name = "InputType";
            this.InputType.Size = new Size(840, 0x15);
            this.InputType.TabIndex = 3;
            this.InputType.SelectedIndexChanged += new EventHandler(this.InputType_SelectedIndexChanged);
            this.InputType.KeyDown += new KeyEventHandler(this.InputType_KeyDown);
            this.InputTypeLabel.Location = new Point(3, 9);
            this.InputTypeLabel.Name = "InputTypeLabel";
            this.InputTypeLabel.Size = new Size(840, 0x10);
            this.InputTypeLabel.TabIndex = 4;
            this.InputTypeLabel.Text = "label1";
            this.InputTypeLabel.TextAlign = ContentAlignment.BottomLeft;
            this.ButtonX.Location = new Point(660, 0x10f);
            this.ButtonX.Name = "ButtonX";
            this.ButtonX.Size = new Size(0x49, 0x24);
            this.ButtonX.TabIndex = 5;
            this.ButtonX.Text = "button1";
            this.ButtonX.UseVisualStyleBackColor = true;
            this.ButtonX.Visible = false;
            this.ButtonX.MouseLeave += new EventHandler(this.Button_HoverLeave);
            this.ButtonX.MouseHover += new EventHandler(this.Button_Hover);
            this.ButtonY.Location = new Point(0x2bf, 0xe0);
            this.ButtonY.Name = "ButtonY";
            this.ButtonY.Size = new Size(0x49, 0x24);
            this.ButtonY.TabIndex = 6;
            this.ButtonY.Text = "button1";
            this.ButtonY.UseVisualStyleBackColor = true;
            this.ButtonY.Visible = false;
            this.ButtonY.MouseLeave += new EventHandler(this.Button_HoverLeave);
            this.ButtonY.MouseHover += new EventHandler(this.Button_Hover);
            this.ButtonRB.Location = new Point(0x281, 0x8d);
            this.ButtonRB.Name = "ButtonRB";
            this.ButtonRB.Size = new Size(0x49, 0x24);
            this.ButtonRB.TabIndex = 10;
            this.ButtonRB.Text = "button1";
            this.ButtonRB.UseVisualStyleBackColor = true;
            this.ButtonRB.Visible = false;
            this.ButtonRB.MouseLeave += new EventHandler(this.Button_HoverLeave);
            this.ButtonRB.MouseHover += new EventHandler(this.Button_Hover);
            this.ButtonLB.Location = new Point(0x88, 0x8d);
            this.ButtonLB.Name = "ButtonLB";
            this.ButtonLB.Size = new Size(0x49, 0x24);
            this.ButtonLB.TabIndex = 9;
            this.ButtonLB.Text = "button1";
            this.ButtonLB.UseVisualStyleBackColor = true;
            this.ButtonLB.Visible = false;
            this.ButtonLB.MouseLeave += new EventHandler(this.Button_HoverLeave);
            this.ButtonLB.MouseHover += new EventHandler(this.Button_Hover);
            this.ButtonBack.Location = new Point(0x157, 0x51);
            this.ButtonBack.Name = "ButtonBack";
            this.ButtonBack.Size = new Size(0x49, 0x24);
            this.ButtonBack.TabIndex = 8;
            this.ButtonBack.Text = "button2";
            this.ButtonBack.UseVisualStyleBackColor = true;
            this.ButtonBack.Visible = false;
            this.ButtonBack.MouseLeave += new EventHandler(this.Button_HoverLeave);
            this.ButtonBack.MouseHover += new EventHandler(this.Button_Hover);
            this.ButtonStart.Location = new Point(0x1b0, 0x51);
            this.ButtonStart.Name = "ButtonStart";
            this.ButtonStart.Size = new Size(0x49, 0x24);
            this.ButtonStart.TabIndex = 7;
            this.ButtonStart.Text = "button1";
            this.ButtonStart.UseVisualStyleBackColor = true;
            this.ButtonStart.Visible = false;
            this.ButtonStart.MouseLeave += new EventHandler(this.Button_HoverLeave);
            this.ButtonStart.MouseHover += new EventHandler(this.Button_Hover);
            this.ButtonLT.Location = new Point(0x88, 0x61);
            this.ButtonLT.Name = "ButtonLT";
            this.ButtonLT.Size = new Size(0x49, 0x24);
            this.ButtonLT.TabIndex = 12;
            this.ButtonLT.Text = "ButtonLT";
            this.ButtonLT.UseVisualStyleBackColor = true;
            this.ButtonLT.Visible = false;
            this.ButtonLT.MouseLeave += new EventHandler(this.Button_HoverLeave);
            this.ButtonLT.MouseHover += new EventHandler(this.Button_Hover);
            this.ButtonRT.Location = new Point(0x281, 0x62);
            this.ButtonRT.Name = "ButtonRT";
            this.ButtonRT.Size = new Size(0x49, 0x24);
            this.ButtonRT.TabIndex = 11;
            this.ButtonRT.Text = "ButtonRT";
            this.ButtonRT.UseVisualStyleBackColor = true;
            this.ButtonRT.Visible = false;
            this.ButtonRT.MouseLeave += new EventHandler(this.Button_HoverLeave);
            this.ButtonRT.MouseHover += new EventHandler(this.Button_Hover);
            this.ButtonStickYD.Location = new Point(0x48, 0x13c);
            this.ButtonStickYD.Name = "ButtonStickYD";
            this.ButtonStickYD.Size = new Size(0x49, 0x24);
            this.ButtonStickYD.TabIndex = 0x10;
            this.ButtonStickYD.Text = "button3";
            this.ButtonStickYD.UseVisualStyleBackColor = true;
            this.ButtonStickYD.Visible = false;
            this.ButtonStickYD.MouseLeave += new EventHandler(this.Button_HoverLeave);
            this.ButtonStickYD.MouseHover += new EventHandler(this.Button_Hover);
            this.ButtonStickXL.Location = new Point(0x1d, 270);
            this.ButtonStickXL.Name = "ButtonStickXL";
            this.ButtonStickXL.Size = new Size(0x49, 0x24);
            this.ButtonStickXL.TabIndex = 15;
            this.ButtonStickXL.Text = "button4";
            this.ButtonStickXL.UseVisualStyleBackColor = true;
            this.ButtonStickXL.Visible = false;
            this.ButtonStickXL.MouseLeave += new EventHandler(this.Button_HoverLeave);
            this.ButtonStickXL.MouseHover += new EventHandler(this.Button_Hover);
            this.ButtonStickYU.Location = new Point(0x48, 0xe0);
            this.ButtonStickYU.Name = "ButtonStickYU";
            this.ButtonStickYU.Size = new Size(0x49, 0x24);
            this.ButtonStickYU.TabIndex = 13;
            this.ButtonStickYU.Text = "Z Rotationri Z Rotation";
            this.ButtonStickYU.UseVisualStyleBackColor = true;
            this.ButtonStickYU.Visible = false;
            this.ButtonStickYU.MouseLeave += new EventHandler(this.Button_HoverLeave);
            this.ButtonStickYU.Click += new EventHandler(this.ButtonStickLX_Click);
            this.ButtonStickYU.MouseHover += new EventHandler(this.Button_Hover);
            this.ButtonStickXR.Location = new Point(0x77, 270);
            this.ButtonStickXR.Name = "ButtonStickXR";
            this.ButtonStickXR.Size = new Size(0x49, 0x24);
            this.ButtonStickXR.TabIndex = 14;
            this.ButtonStickXR.Text = "button2";
            this.ButtonStickXR.UseVisualStyleBackColor = true;
            this.ButtonStickXR.Visible = false;
            this.ButtonStickXR.MouseLeave += new EventHandler(this.Button_HoverLeave);
            this.ButtonStickXR.MouseHover += new EventHandler(this.Button_Hover);
            this.ResetDefaultButton.Location = new Point(0x179, 0x187);
            this.ResetDefaultButton.Name = "ResetDefaultButton";
            this.ResetDefaultButton.Size = new Size(0x5b, 0x29);
            this.ResetDefaultButton.TabIndex = 0x11;
            this.ResetDefaultButton.Text = "Reset to Default";
            this.ResetDefaultButton.UseVisualStyleBackColor = true;
            this.ResetDefaultButton.Visible = false;
            this.ResetDefaultButton.Click += new EventHandler(this.ResetDefaultButton_Click);
            this.pictureBox1.Image = (Image) manager.GetObject("pictureBox1.Image");
            this.pictureBox1.Location = new Point(6, 0x37);
            this.pictureBox1.Name = "pictureBox1";
            this.pictureBox1.Size = new Size(0x342, 0x193);
            this.pictureBox1.SizeMode = PictureBoxSizeMode.AutoSize;
            this.pictureBox1.TabIndex = 0x12;
            this.pictureBox1.TabStop = false;
            this.pictureBox1.Visible = false;
            this.Instructions_label.BackColor = SystemColors.AppWorkspace;
            this.Instructions_label.Location = new Point(12, 0x1b3);
            this.Instructions_label.Name = "Instructions_label";
            this.Instructions_label.Size = new Size(0x337, 0x15);
            this.Instructions_label.TabIndex = 0x13;
            this.Instructions_label.Text = "To change a button mapping hover the mouse pointer over a button and then press the key / button on the selected input device that you wish to assign,";
            this.Instructions_label.TextAlign = ContentAlignment.MiddleCenter;
            this.pictureBox2.Image = (Image) manager.GetObject("pictureBox2.Image");
            this.pictureBox2.Location = new Point(6, 0x37);
            this.pictureBox2.Name = "pictureBox2";
            this.pictureBox2.Size = new Size(0x342, 0x193);
            this.pictureBox2.TabIndex = 20;
            this.pictureBox2.TabStop = false;
            this.StartButtonInstructions_Label.Font = new Font("Microsoft Sans Serif", 8.25f, FontStyle.Bold, GraphicsUnit.Point, 0);
            this.StartButtonInstructions_Label.Location = new Point(0x5c, 4);
            this.StartButtonInstructions_Label.Name = "StartButtonInstructions_Label";
            this.StartButtonInstructions_Label.Size = new Size(670, 0x15);
            this.StartButtonInstructions_Label.TabIndex = 0x15;
            this.StartButtonInstructions_Label.Text = "label1";
            this.StartButtonInstructions_Label.TextAlign = ContentAlignment.MiddleCenter;
            base.AutoScaleDimensions = new SizeF(6f, 13f);
            base.AutoScaleMode = AutoScaleMode.Font;
            base.BorderStyle = BorderStyle.FixedSingle;
            base.Controls.Add(this.StartButtonInstructions_Label);
            base.Controls.Add(this.Instructions_label);
            base.Controls.Add(this.ResetDefaultButton);
            base.Controls.Add(this.ButtonStickYD);
            base.Controls.Add(this.ButtonStickXL);
            base.Controls.Add(this.ButtonStickXR);
            base.Controls.Add(this.ButtonStickYU);
            base.Controls.Add(this.ButtonLT);
            base.Controls.Add(this.ButtonRT);
            base.Controls.Add(this.ButtonRB);
            base.Controls.Add(this.ButtonLB);
            base.Controls.Add(this.ButtonBack);
            base.Controls.Add(this.ButtonStart);
            base.Controls.Add(this.ButtonY);
            base.Controls.Add(this.ButtonX);
            base.Controls.Add(this.InputTypeLabel);
            base.Controls.Add(this.InputType);
            base.Controls.Add(this.ButtonB);
            base.Controls.Add(this.ButtonA);
            base.Controls.Add(this.pictureBox1);
            base.Controls.Add(this.pictureBox2);
            base.Name = "InputConfiguration";
            base.Size = new Size(0x34e, 460);
            base.Load += new EventHandler(this.InputConfiguration_Load);
            ((ISupportInitialize) this.pictureBox1).EndInit();
            ((ISupportInitialize) this.pictureBox2).EndInit();
            base.ResumeLayout(false);
            base.PerformLayout();
        }

        private void InputConfiguration_Load(object sender, EventArgs e)
        {
            this.InputUpdateTimer = new Timer();
            this.InputUpdateTimer.Tick += new EventHandler(this.InputUpdateTimer_Tick);
            this.InputUpdateTimer.Interval = 100;
            this.InputUpdateTimer.Start();
            this.ResetTimer = new Timer();
            this.ResetTimer.Tick += new EventHandler(this.ResetTimer_Tick);
            this.ResetTimer.Interval = 0x5dc;
            ButtonConfig item = new ButtonConfig();
            item.mButtonHandle = this.ButtonA;
            this.mButtonList.Add(item);
            item = new ButtonConfig();
            item.mButtonHandle = this.ButtonX;
            this.mButtonList.Add(item);
            item = new ButtonConfig();
            item.mButtonHandle = this.ButtonY;
            this.mButtonList.Add(item);
            item = new ButtonConfig();
            item.mButtonHandle = this.ButtonB;
            this.mButtonList.Add(item);
            item = new ButtonConfig();
            item.mButtonHandle = this.ButtonStart;
            this.mButtonList.Add(item);
            item = new ButtonConfig();
            item.mButtonHandle = this.ButtonBack;
            this.mButtonList.Add(item);
            item = new ButtonConfig();
            item.mButtonHandle = this.ButtonLB;
            this.mButtonList.Add(item);
            item = new ButtonConfig();
            item.mButtonHandle = this.ButtonRB;
            this.mButtonList.Add(item);
            item = new ButtonConfig();
            item.mButtonHandle = this.ButtonLT;
            this.mButtonList.Add(item);
            item = new ButtonConfig();
            item.mButtonHandle = this.ButtonRT;
            this.mButtonList.Add(item);
            item = new ButtonConfig();
            item.mButtonHandle = this.ButtonStickYU;
            this.mMovementButtonList.Add(item);
            this.mMovementButtonPairY.Add(item);
            this.mButtonList.Add(item);
            item = new ButtonConfig();
            item.mButtonHandle = this.ButtonStickYD;
            this.mMovementButtonList.Add(item);
            this.mMovementButtonPairY.Add(item);
            this.mButtonList.Add(item);
            item = new ButtonConfig();
            item.mButtonHandle = this.ButtonStickXR;
            this.mMovementButtonList.Add(item);
            this.mMovementButtonPairX.Add(item);
            this.mButtonList.Add(item);
            item = new ButtonConfig();
            item.mButtonHandle = this.ButtonStickXL;
            this.mMovementButtonList.Add(item);
            this.mMovementButtonPairX.Add(item);
            this.mButtonList.Add(item);
            this.InitControllerSelections();
            this.SetFormText();
        }

        private void InputType_KeyDown(object sender, KeyEventArgs e)
        {
            e.SuppressKeyPress = true;
        }

        private void InputType_SelectedIndexChanged(object sender, EventArgs e)
        {
            this.bRefreshButtons = true;
        }

        private void InputUpdateTimer_Tick(object sender, EventArgs e)
        {
            if (this.bRefreshButtons)
            {
                this.RefreshButtons();
            }
            if (this.ActiveButton != null)
            {
                sPressInfo info2;
                PadInfo info = (PadInfo) this.InputType.Items[this.InputType.SelectedIndex];
                switch (info.mPadType)
                {
                    case PadInfo.PAD_TYPE.PAD_TYPE_LEGACY:
                        if (!DllExterns._PollPad())
                        {
                            return;
                        }
                        info2 = new sPressInfo();
                        DllExterns._GetPadPressInfo(info2, info.mInstanceID);
                        if (info2.m_Type == sPressInfo.PressType.PT_None)
                        {
                            foreach (PadInfo info3 in this.mPadInfoList)
                            {
                                if ((info.mInstanceID != info3.mInstanceID) && (info.mProductGuid == info3.mProductGuid))
                                {
                                    DllExterns._GetPadPressInfo(info2, info3.mInstanceID);
                                    if (info2.m_Type != sPressInfo.PressType.PT_None)
                                    {
                                        break;
                                    }
                                }
                            }
                        }
                        break;

                    case PadInfo.PAD_TYPE.PAD_TYPE_KEYBOARD:
                        if (DllExterns._PollKeyboard())
                        {
                            int num = DllExterns._GetKeyboardPressed();
                            if (num == -1)
                            {
                                return;
                            }
                            foreach (ButtonConfig config in this.mButtonList)
                            {
                                if (config.mButtonHandle != this.ActiveButton)
                                {
                                    continue;
                                }
                                config.Reset();
                                config.mKeyboardKey = (uint) num;
                                switch (num)
                                {
                                    case 0xcb:
                                        config.mButtonHandle.Text = "Left";
                                        break;

                                    case 0xcd:
                                        config.mButtonHandle.Text = "Right";
                                        break;

                                    case 0xd0:
                                        config.mButtonHandle.Text = "Down";
                                        break;

                                    case 200:
                                        config.mButtonHandle.Text = "Up";
                                        break;

                                    default:
                                        config.mButtonHandle.Text = Enum.Parse(typeof(Keys), DllExterns._GetKeyboardPressedAscii().ToString()).ToString();
                                        break;
                                }
                                foreach (ButtonConfig config2 in this.mButtonList)
                                {
                                    if ((config2 != config) && (config2.mKeyboardKey == config.mKeyboardKey))
                                    {
                                        config2.Reset();
                                        config2.mButtonHandle.Text = LocalizedText.Undefined;
                                    }
                                }
                            }
                            this.UpdateButtonConfiguration();
                        }
                        return;

                    default:
                        return;
                }
                switch (info2.m_Type)
                {
                    case sPressInfo.PressType.PT_Axis:
                    case sPressInfo.PressType.PT_Rotation:
                    {
                        bool flag = false;
                        foreach (ButtonConfig config7 in this.mMovementButtonPairY)
                        {
                            if (config7.mButtonHandle != this.ActiveButton)
                            {
                                continue;
                            }
                            if (this.MovementInputType != 1)
                            {
                                foreach (ButtonConfig config8 in this.mMovementButtonList)
                                {
                                    config8.Reset();
                                    config8.mButtonHandle.Text = LocalizedText.Undefined;
                                }
                            }
                            this.MovementInputType = 1;
                            flag = true;
                        }
                        if (flag)
                        {
                            byte index = info2.m_Index;
                            if (info2.m_Type == sPressInfo.PressType.PT_Rotation)
                            {
                                index = 4;
                            }
                            else
                            {
                                index = (byte) (index + 1);
                            }
                            foreach (ButtonConfig config9 in this.mMovementButtonPairY)
                            {
                                config9.Reset();
                                config9.mButtonHandle.Text = info2.m_tszName;
                                config9.mPressInfo = info2;
                                config9.mPressInfo.m_Index = index;
                            }
                            if ((this.mMovementButtonPairX[0].mPressInfo.m_Type == info2.m_Type) && (this.mMovementButtonPairX[0].mPressInfo.m_Index == index))
                            {
                                foreach (ButtonConfig config10 in this.mMovementButtonPairX)
                                {
                                    config10.Reset();
                                    config10.mButtonHandle.Text = LocalizedText.Undefined;
                                }
                            }
                            break;
                        }
                        foreach (ButtonConfig config11 in this.mMovementButtonPairX)
                        {
                            if (config11.mButtonHandle != this.ActiveButton)
                            {
                                continue;
                            }
                            if (this.MovementInputType != 1)
                            {
                                foreach (ButtonConfig config12 in this.mMovementButtonList)
                                {
                                    config12.Reset();
                                    config12.mButtonHandle.Text = LocalizedText.Undefined;
                                }
                            }
                            this.MovementInputType = 1;
                            flag = true;
                        }
                        if (flag)
                        {
                            byte num3 = info2.m_Index;
                            if (info2.m_Type == sPressInfo.PressType.PT_Rotation)
                            {
                                num3 = 4;
                            }
                            else
                            {
                                num3 = (byte) (num3 + 1);
                            }
                            foreach (ButtonConfig config13 in this.mMovementButtonPairX)
                            {
                                config13.Reset();
                                config13.mButtonHandle.Text = info2.m_tszName;
                                config13.mPressInfo = info2;
                                config13.mPressInfo.m_Index = num3;
                            }
                            if ((this.mMovementButtonPairY[0].mPressInfo.m_Type == info2.m_Type) && (this.mMovementButtonPairY[0].mPressInfo.m_Index == num3))
                            {
                                foreach (ButtonConfig config14 in this.mMovementButtonPairY)
                                {
                                    config14.Reset();
                                    config14.mButtonHandle.Text = LocalizedText.Undefined;
                                }
                            }
                        }
                        break;
                    }
                    case sPressInfo.PressType.PT_Pov:
                        foreach (ButtonConfig config15 in this.mMovementButtonList)
                        {
                            if (config15.mButtonHandle != this.ActiveButton)
                            {
                                continue;
                            }
                            if (this.MovementInputType != 0)
                            {
                                foreach (ButtonConfig config16 in this.mMovementButtonList)
                                {
                                    config16.Reset();
                                    config16.mButtonHandle.Text = "D-Pad";
                                }
                            }
                            this.MovementInputType = 0;
                        }
                        break;

                    case sPressInfo.PressType.PT_Button:
                        foreach (ButtonConfig config3 in this.mMovementButtonList)
                        {
                            if (config3.mButtonHandle != this.ActiveButton)
                            {
                                continue;
                            }
                            if (this.MovementInputType != 2)
                            {
                                foreach (ButtonConfig config4 in this.mMovementButtonList)
                                {
                                    if (config4.mButtonHandle != this.ActiveButton)
                                    {
                                        config4.Reset();
                                        config4.mButtonHandle.Text = LocalizedText.Undefined;
                                    }
                                }
                            }
                            this.MovementInputType = 2;
                        }
                        foreach (ButtonConfig config5 in this.mButtonList)
                        {
                            if (config5.mButtonHandle == this.ActiveButton)
                            {
                                config5.Reset();
                                config5.mPressInfo = info2;
                                config5.mPressInfo.m_Index = (byte) (config5.mPressInfo.m_Index + 1);
                                config5.mButtonHandle.Text = "Button " + config5.mPressInfo.m_Index;
                                foreach (ButtonConfig config6 in this.mButtonList)
                                {
                                    if (((config6 != config5) && (config6.mPressInfo.m_Type == config5.mPressInfo.m_Type)) && (config6.mPressInfo.m_Index == config5.mPressInfo.m_Index))
                                    {
                                        config6.Reset();
                                        config6.mButtonHandle.Text = LocalizedText.Undefined;
                                    }
                                }
                                continue;
                            }
                        }
                        break;

                    case sPressInfo.PressType.PT_None:
                        return;
                }
                this.UpdateButtonConfiguration();
            }
        }

        public void RefreshButtons()
        {
            foreach (ButtonConfig config in this.mButtonList)
            {
                config.Reset();
            }
            OutputConfig config2 = null;
            PadInfo info = (PadInfo) this.InputType.Items[this.InputType.SelectedIndex];
            GlobalDefs defs = new GlobalDefs();
            if ((info.mPadType == PadInfo.PAD_TYPE.PAD_TYPE_XBOX) || (info.mProductGuid == defs.ZERO_GUID))
            {
                this.ResetDefaultButton.Enabled = false;
                this.ResetDefaultButton.Visible = false;
                this.Instructions_label.Visible = false;
                foreach (ButtonConfig config3 in this.mButtonList)
                {
                    config3.mButtonHandle.Enabled = false;
                    config3.mButtonHandle.Visible = false;
                }
                this.pictureBox1.Visible = false;
            }
            else
            {
                this.ResetDefaultButton.Enabled = true;
                this.ResetDefaultButton.Visible = true;
                this.Instructions_label.Visible = true;
                foreach (ButtonConfig config4 in this.mButtonList)
                {
                    config4.mButtonHandle.Enabled = true;
                    config4.mButtonHandle.Visible = true;
                }
                this.pictureBox1.Visible = true;
            }
            foreach (OutputConfig config5 in GlobalDefs.OutputConfigList)
            {
                if (info.mProductGuid == config5.mProductGuid)
                {
                    config2 = config5;
                    break;
                }
            }
            if (config2 != null)
            {
                int num;
                this.bRefreshButtons = false;
                switch (info.mPadType)
                {
                    case PadInfo.PAD_TYPE.PAD_TYPE_LEGACY:
                        this.MovementInputType = config2.mMovementType;
                        num = 0;
                        foreach (ButtonConfig config8 in this.mButtonList)
                        {
                            config8.Reset();
                            uint num3 = (uint) config2.mButtonMap[num];
                            if (num3 != 0)
                            {
                                config8.mPressInfo.m_Index = (byte) num3;
                                config8.mPressInfo.m_Type = sPressInfo.PressType.PT_Button;
                                config8.mButtonHandle.Text = "Button " + num3;
                            }
                            num++;
                            if (num >= config2.mButtonMap.Length)
                            {
                                break;
                            }
                        }
                        break;

                    case PadInfo.PAD_TYPE.PAD_TYPE_KEYBOARD:
                        foreach (ButtonConfig config6 in this.mMovementButtonList)
                        {
                            config6.Reset();
                        }
                        this.MovementInputType = config2.mMovementType;
                        num = 0;
                        foreach (ButtonConfig config7 in this.mButtonList)
                        {
                            config7.Reset();
                            if (config2.mButtonMap[num] != 0)
                            {
                                config7.mKeyboardKey = (uint) config2.mButtonMap[num];
                                switch (config7.mKeyboardKey)
                                {
                                    case 0xcb:
                                        config7.mButtonHandle.Text = LocalizedText.Keyboard_Left;
                                        goto Label_0324;

                                    case 0xcd:
                                        config7.mButtonHandle.Text = LocalizedText.Keyboard_Right;
                                        goto Label_0324;

                                    case 0xd0:
                                        config7.mButtonHandle.Text = LocalizedText.Keyboard_Down;
                                        goto Label_0324;

                                    case 200:
                                        config7.mButtonHandle.Text = LocalizedText.Keyboard_Up;
                                        goto Label_0324;
                                }
                                config7.mButtonHandle.Text = Enum.Parse(typeof(Keys), DllExterns._ConvertToAscii((int) config7.mKeyboardKey).ToString()).ToString();
                            }
                        Label_0324:
                            num++;
                            if (num >= config2.mButtonMap.Length)
                            {
                                break;
                            }
                        }
                        return;

                    default:
                        return;
                }
                switch (this.MovementInputType)
                {
                    case 0:
                        foreach (ButtonConfig config9 in this.mMovementButtonList)
                        {
                            config9.Reset();
                            config9.mButtonHandle.Text = "D-Pad";
                        }
                        return;

                    case 1:
                        num = 0;
                        foreach (ButtonConfig config10 in this.mMovementButtonList)
                        {
                            config10.Reset();
                            uint num4 = (uint) config2.mAxisMap[num];
                            if (num4 != 0)
                            {
                                config10.mPressInfo.m_Index = (byte) num4;
                                config10.mPressInfo.m_Type = sPressInfo.PressType.PT_Axis;
                                switch (num4)
                                {
                                    case 1:
                                        config10.mButtonHandle.Text = "X Axis";
                                        config10.mPressInfo.m_tszName = "X Axis";
                                        break;

                                    case 2:
                                        config10.mButtonHandle.Text = "Y Axis";
                                        config10.mPressInfo.m_tszName = "Y Axis";
                                        break;

                                    case 3:
                                        config10.mButtonHandle.Text = "Z Axis";
                                        config10.mPressInfo.m_tszName = "Z Axis";
                                        break;

                                    case 4:
                                        config10.mButtonHandle.Text = "Z Rotation";
                                        config10.mPressInfo.m_tszName = "Z Rotation";
                                        config10.mPressInfo.m_Type = sPressInfo.PressType.PT_Rotation;
                                        break;
                                }
                            }
                            num++;
                            if (num >= config2.mAxisMap.Length)
                            {
                                break;
                            }
                        }
                        return;

                    case 2:
                        return;

                    default:
                        return;
                }
            }
        }

        private void ResetDefaultButton_Click(object sender, EventArgs e)
        {
            FileHandler handler = new FileHandler();
            int padIndex = 0;
            string path = "DefaultInput.cfg";
            if (!File.Exists(path))
            {
                MessageBox.Show(LocalizedText.DefaultInputMissing, LocalizedText.Error, MessageBoxButtons.OK, MessageBoxIcon.None);
            }
            else
            {
                PadInfo info = (PadInfo) this.InputType.Items[this.InputType.SelectedIndex];
                foreach (OutputConfig config in GlobalDefs.OutputConfigList)
                {
                    if (info.mProductGuid == config.mProductGuid)
                    {
                        handler.LoadInfoConfig(path, padIndex);
                        break;
                    }
                    padIndex++;
                }
                this.RefreshButtons();
            }
        }

        public void ResetPadListData()
        {
            if (!this.ResetTimer.Enabled)
            {
                this.ResetTimer.Start();
            }
        }

        private void ResetTimer_Tick(object sender, EventArgs e)
        {
            this.InputUpdateTimer.Stop();
            this.ResetTimer.Stop();
            DllExterns._ResetPadLists();
            this.InitControllerSelections();
            this.InputUpdateTimer.Start();
        }

        private void SetFormText()
        {
            this.InputTypeLabel.Text = LocalizedText.InputTypeLabel;
            this.Instructions_label.Text = LocalizedText.Pad_Instructions;
            this.ResetDefaultButton.Text = LocalizedText.ResetDefaultButton;
            this.StartButtonInstructions_Label.Text = LocalizedText.SwitchPadInstruction_label;
        }

        public void UpdateButtonConfiguration()
        {
            PadInfo info = (PadInfo) this.InputType.Items[this.InputType.SelectedIndex];
            switch (info.mPadType)
            {
                case PadInfo.PAD_TYPE.PAD_TYPE_LEGACY:
                    foreach (OutputConfig config3 in GlobalDefs.OutputConfigList)
                    {
                        if (config3.mProductGuid == info.mProductGuid)
                        {
                            config3.mMovementType = this.MovementInputType;
                            for (int i = 0; i < config3.mButtonMap.Length; i++)
                            {
                                config3.mButtonMap[i] = 0;
                            }
                            for (int j = 0; j < config3.mAxisMap.Length; j++)
                            {
                                config3.mAxisMap[j] = 0;
                            }
                            int index = 0;
                            foreach (ButtonConfig config4 in this.mButtonList)
                            {
                                if (index < config3.mButtonMap.Length)
                                {
                                    config3.mButtonMap[index] = config4.mPressInfo.m_Index;
                                    index++;
                                }
                            }
                            int num5 = 0;
                            foreach (ButtonConfig config5 in this.mMovementButtonList)
                            {
                                if (num5 < config3.mAxisMap.Length)
                                {
                                    config3.mAxisMap[num5] = config5.mPressInfo.m_Index;
                                    num5++;
                                }
                            }
                            continue;
                        }
                    }
                    break;

                case PadInfo.PAD_TYPE.PAD_TYPE_KEYBOARD:
                    foreach (OutputConfig config in GlobalDefs.OutputConfigList)
                    {
                        if (config.mProductGuid == info.mProductGuid)
                        {
                            int num = 0;
                            config.mMovementType = 2;
                            foreach (ButtonConfig config2 in this.mButtonList)
                            {
                                config.mButtonMap[num] = (int) config2.mKeyboardKey;
                                num++;
                                if (num >= config.mButtonMap.Length)
                                {
                                    break;
                                }
                            }
                            continue;
                        }
                    }
                    break;

                default:
                    return;
            }
        }

        public void UpdateConfigList()
        {
            if (GlobalDefs.OutputConfigList.Count > 0)
            {
                foreach (PadInfo info in this.mGuidPadInfoList)
                {
                    bool flag = false;
                    foreach (OutputConfig config in GlobalDefs.OutputConfigList)
                    {
                        if (config.mProductGuid == info.mProductGuid)
                        {
                            flag = true;
                        }
                    }
                    if (!flag)
                    {
                        OutputConfig item = new OutputConfig();
                        item.mProductGuid = info.mProductGuid;
                        item.mProductName = info.mProductName;
                        GlobalDefs.OutputConfigList.Add(item);
                        Console.WriteLine("Added To Config List : " + item.mProductName);
                    }
                }
            }
            else
            {
                foreach (PadInfo info2 in this.mGuidPadInfoList)
                {
                    OutputConfig config3 = new OutputConfig();
                    config3.mProductGuid = info2.mProductGuid;
                    config3.mProductName = info2.mProductName;
                    GlobalDefs.OutputConfigList.Add(config3);
                }
                foreach (OutputConfig config4 in GlobalDefs.OutputConfigList)
                {
                    Console.WriteLine("Added To Config List : " + config4.mProductName);
                }
            }
        }
    }
}
